@@ -1,8 +1,10 @@
 from __future__ import absolute_import
 
-__version__ = '0.0.7'
+__version__ = "0.4.6"
 
 from .core.composition import *
 from .core.transforms_interface import *
+from .core.serialization import *
 from .augmentations.transforms import *
+from .augmentations.bbox_utils import *
 from .imgaug.transforms import *
